import{a0 as n,r as t,o as s,c as r}from"./index.b7b4bda7.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},c=new Error().stack;c&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[c]="ced8c325-ccda-4924-8094-52c15ce52992",e._sentryDebugIdIdentifier="sentry-dbid-ced8c325-ccda-4924-8094-52c15ce52992")}catch{}})();const d={};function _(e,c){const o=t("RouterView");return s(),r(o,{class:"router"})}const f=n(d,[["render",_],["__scopeId","data-v-3c2b9654"]]);export{f as default};
//# sourceMappingURL=Home.4588a430.js.map
