import{_ as i}from"./Login.vue_vue_type_script_setup_true_lang.44c55415.js";import{d as _,eo as m,ea as f,o as l,Y as b,b as y,u as p,a0 as g}from"./index.b7b4bda7.js";import{u as w}from"./workspaceStore.be088758.js";import"./Logo.23971e4c.js";import"./string.197ece6b.js";import"./CircularLoading.cd21e035.js";import"./index.9347e471.js";import"./index.c62cc8cf.js";import"./url.b5db0ec0.js";import"./colorHelpers.4deb51e0.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="2a8ea49b-2b14-497c-85bd-42358cd7a7c1",e._sentryDebugIdIdentifier="sentry-dbid-2a8ea49b-2b14-497c-85bd-42358cd7a7c1")}catch{}})();const k={class:"runner"},h=_({__name:"Login",setup(e){const o=m(),r=f(),s=w(),u=async()=>{const{redirect:t,...a}=r.query;if(t){await o.push({path:t,query:a,params:r.params});return}o.push({name:"playerHome",query:a})};return(t,a)=>{var n,c,d;return l(),b("div",k,[y(i,{"logo-url":(c=(n=p(s).state.workspace)==null?void 0:n.logoUrl)!=null?c:void 0,"brand-name":(d=p(s).state.workspace)==null?void 0:d.brandName,onDone:u},null,8,["logo-url","brand-name"])])}}});const S=g(h,[["__scopeId","data-v-a7e3f7bf"]]);export{S as default};
//# sourceMappingURL=Login.48feb8ec.js.map
