import{U as a,dA as i,dB as c}from"./index.b7b4bda7.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="6300911f-3df6-49de-816e-7d18b4e01d30",e._sentryDebugIdIdentifier="sentry-dbid-6300911f-3df6-49de-816e-7d18b4e01d30")}catch{}})();const{DatePicker:n,WeekPicker:t,MonthPicker:r,YearPicker:f,TimePicker:m,QuarterPicker:d,RangePicker:o}=i(c),y=a(n,{WeekPicker:t,MonthPicker:r,YearPicker:f,RangePicker:o,TimePicker:m,QuarterPicker:d,install:e=>(e.component(n.name,n),e.component(o.name,o),e.component(r.name,r),e.component(t.name,t),e.component(d.name,d),e)});export{y as D,r as M,d as Q,o as R,t as W};
//# sourceMappingURL=dayjs.dd0c2b2c.js.map
