import{P as f}from"./PlayerNavbar.ea9e30f1.js";import{d as g,eo as b,ea as i,e as h,f as y,r as k,o as c,Y as v,u as n,c as w,S as L,a as C,b as I,a0 as N}from"./index.b7b4bda7.js";import{u as V}from"./workspaceStore.be088758.js";import"./metadata.f73a9e6d.js";import"./PhBug.vue.118d6a4b.js";import"./PhCheckCircle.vue.9e92f7a6.js";import"./PhKanban.vue.7adc1b7a.js";import"./PhWebhooksLogo.vue.9fa90918.js";import"./LoadingOutlined.efc83666.js";import"./PhSignOut.vue.43269362.js";import"./index.266b0911.js";import"./Avatar.5b164d81.js";import"./url.b5db0ec0.js";import"./colorHelpers.4deb51e0.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="b91b8779-7c87-4d7a-ba54-9bcf19da725b",o._sentryDebugIdIdentifier="sentry-dbid-b91b8779-7c87-4d7a-ba54-9bcf19da725b")}catch{}})();const x={class:"main-container"},B={class:"content"},D=g({__name:"Main",setup(o){const e=b(),t=V(),d=i().path,a=h(null),u=async({path:r,id:s})=>{a.value=s,await e.push({path:`/${r}`}),a.value=null},p=()=>{e.push({name:"playerLogin"})},l=()=>{e.push({name:"playerLogin"})},_=y(()=>!!i().meta.hideLogin);return(r,s)=>{const m=k("RouterView");return c(),v("div",x,[n(t).state.workspace?(c(),w(f,{key:0,"current-path":n(d),"hide-login":_.value,"runner-data":n(t).state.workspace,loading:a.value,onNavigate:u,onLoginClick:l,onLogoutClick:p},null,8,["current-path","hide-login","runner-data","loading"])):L("",!0),C("section",B,[I(m)])])}}});const H=N(D,[["__scopeId","data-v-f095bece"]]);export{H as default};
//# sourceMappingURL=Main.4363b181.js.map
