import{O as r}from"./workspaceStore.be088758.js";import{d as c,X as l,o as i,Y as u,b as a,w as d,u as o,aG as n,dd as f,dc as _}from"./index.b7b4bda7.js";import"./url.b5db0ec0.js";import"./colorHelpers.4deb51e0.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="c3173ad1-6704-43c6-9426-da67d8cdc080",e._sentryDebugIdIdentifier="sentry-dbid-c3173ad1-6704-43c6-9426-da67d8cdc080")}catch{}})();const b=c({__name:"OidcLogoutCallback",setup(e){return l(async()=>{await new r().logoutCallback()}),(t,s)=>(i(),u("div",null,[a(o(f),null,{default:d(()=>[n("You're authenticated")]),_:1}),a(o(_),null,{default:d(()=>[n(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{b as default};
//# sourceMappingURL=OidcLogoutCallback.4476eee9.js.map
