import{d as a,o as d,Y as o,b as s,u as c,by as r,a0 as _}from"./index.b7b4bda7.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="a7bdbd12-a5ff-46bc-83dc-038c02457861",e._sentryDebugIdIdentifier="sentry-dbid-a7bdbd12-a5ff-46bc-83dc-038c02457861")}catch{}})();const i={class:"centered"},f=a({__name:"LoadingContainer",setup(e){return(n,t)=>(d(),o("div",i,[s(c(r))]))}});const p=_(f,[["__scopeId","data-v-52e6209a"]]);export{p as L};
//# sourceMappingURL=LoadingContainer.11eb326e.js.map
