import{O as r}from"./workspaceStore.be088758.js";import{d as i,X as l,o as c,Y as u,b as n,w as a,u as o,aG as s,dd as f,dc as b}from"./index.b7b4bda7.js";import"./url.b5db0ec0.js";import"./colorHelpers.4deb51e0.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="9176b282-7d04-4f3c-b964-49f4073fce4e",e._sentryDebugIdIdentifier="sentry-dbid-9176b282-7d04-4f3c-b964-49f4073fce4e")}catch{}})();const w=i({__name:"OidcLoginCallback",setup(e){return l(async()=>{await new r().loginCallback()}),(t,d)=>(c(),u("div",null,[n(o(f),null,{default:a(()=>[s("You're authenticated")]),_:1}),n(o(b),null,{default:a(()=>[s(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{w as default};
//# sourceMappingURL=OidcLoginCallback.a37ded3c.js.map
