import"./index.b7b4bda7.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="829ab0ba-21f1-44cb-bd9f-05fa1aaeea93",e._sentryDebugIdIdentifier="sentry-dbid-829ab0ba-21f1-44cb-bd9f-05fa1aaeea93")}catch{}})();const i=1e3,s=e=>{let n=null;return{startPolling:()=>{const t=async()=>{var o;try{!document.hidden&&!e.keepPollingOnOutOfFocus&&await e.task()}finally{n=setTimeout(t,(o=e.interval)!=null?o:i)}};t()},endPolling:()=>{n&&clearTimeout(n)}}};export{s as u};
//# sourceMappingURL=polling.6fdb889c.js.map
