import"./index.b7b4bda7.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},d=new Error().stack;d&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[d]="375d4e78-8dcc-42f1-be11-6fcfd126c7c9",e._sentryDebugIdIdentifier="sentry-dbid-375d4e78-8dcc-42f1-be11-6fcfd126c7c9")}catch{}})();const t=(...e)=>window.fetch(...e);export{t as l};
//# sourceMappingURL=fetch.0c0bfc81.js.map
