import{d as l,eh as c,f as d,o as t,Y as a,S as r,e9 as _,a0 as g}from"./index.b7b4bda7.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="10e8f58e-ee0c-4896-8204-72408415d9d8",e._sentryDebugIdIdentifier="sentry-dbid-10e8f58e-ee0c-4896-8204-72408415d9d8")}catch{}})();const p={class:"logo"},u=["src","alt"],f={key:1},m=l({__name:"Logo",props:{imageUrl:{},brandName:{},hideText:{type:Boolean},size:{}},setup(e){const o=e;c(s=>({"4352941e":n.value}));const n=d(()=>o.size==="large"?"80px":"50px"),i=d(()=>`${o.brandName} Logo`);return(s,y)=>(t(),a("div",p,[s.imageUrl?(t(),a("img",{key:0,class:"logo-img",src:s.imageUrl,alt:i.value},null,8,u)):r("",!0),s.hideText?r("",!0):(t(),a("span",f,_(s.brandName),1))]))}});const h=g(m,[["__scopeId","data-v-16688d14"]]);export{h as L};
//# sourceMappingURL=Logo.23971e4c.js.map
