import{k as n,T as a,m as r,P as o,C as d,M as p,s as f,n as s,p as c,q as m,t as u,v as g}from"./index.b7b4bda7.js";import{s as y,c as l,a as i}from"./workspaceStore.be088758.js";import{_ as b}from"./App.vue_vue_type_style_index_0_lang.92016307.js";import"./url.b5db0ec0.js";import"./colorHelpers.4deb51e0.js";import"./PlayerConfigProvider.20b856a4.js";import"./index.9347e471.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="8f242645-8d40-431e-9e32-11ba2e3f8f48",t._sentryDebugIdIdentifier="sentry-dbid-8f242645-8d40-431e-9e32-11ba2e3f8f48")}catch{}})();class w{static init(){setInterval(()=>fetch("/_version"),20*1e3)}}(async()=>{await y();const t=l(),e=n({render:()=>c(b)});a.init(),r(e,i),w.init(),e.use(i),e.use(t),e.use(o),e.mount("#app"),e.component("VSelect",d),e.component("Markdown",p),e.component("Message",f),s(e,m),s(e,u),s(e,g)})();
//# sourceMappingURL=player.427989a4.js.map
