import{E as y}from"./api.32608525.js";import{C as w}from"./ContentLayout.7bb666b7.js";import{d as c,N as g,O as f,e as _,o as a,c as i,w as l,b as n,u as o,S as s}from"./index.b7b4bda7.js";import{K as v,_ as K,W as E,E as R,a as T}from"./WorkflowView.5583ee37.js";import{A as p,T as V}from"./TabPane.5704c3a4.js";import"./fetch.0c0bfc81.js";import"./metadata.f73a9e6d.js";import"./PhBug.vue.118d6a4b.js";import"./PhCheckCircle.vue.9e92f7a6.js";import"./PhKanban.vue.7adc1b7a.js";import"./PhWebhooksLogo.vue.9fa90918.js";import"./polling.6fdb889c.js";import"./asyncComputed.03aca0e0.js";import"./PhQuestion.vue.e7767674.js";import"./ant-design.ac080b8a.js";import"./index.2876f94f.js";import"./index.1175d125.js";import"./index.cc331dad.js";import"./CollapsePanel.3164fa4e.js";import"./index.0abd7f87.js";import"./index.d09c6f04.js";import"./Badge.aaf7165e.js";import"./PhArrowCounterClockwise.vue.1e2410e8.js";import"./Workflow.35b663bd.js";import"./validations.1b9832d9.js";import"./string.197ece6b.js";import"./uuid.03b90e20.js";import"./index.9347e471.js";import"./workspaces.a607659d.js";import"./workspaceStore.be088758.js";import"./url.b5db0ec0.js";import"./colorHelpers.4deb51e0.js";import"./record.c4002da6.js";import"./index.3b650aac.js";import"./PhArrowDown.vue.227d46aa.js";import"./Card.dc945fe7.js";import"./LoadingOutlined.efc83666.js";import"./DeleteOutlined.5cd95db0.js";import"./PhDownloadSimple.vue.a41e9d72.js";import"./utils.90a8fe9e.js";import"./LoadingContainer.11eb326e.js";(function(){try{var r=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(r._sentryDebugIds=r._sentryDebugIds||{},r._sentryDebugIds[t]="8ad4e10f-b701-4f4f-bea0-42b770850424",r._sentryDebugIdIdentifier="sentry-dbid-8ad4e10f-b701-4f4f-bea0-42b770850424")}catch{}})();const yo=c({__name:"WorkflowThreads",setup(r){const t=new R,m=new T,u=new g(f.array(f.string()),"kanban-selected-stages"),k=new y,e=_("kanban");return(W,b)=>(a(),i(w,{"full-width":""},{default:l(()=>[n(o(V),{activeKey:e.value,"onUpdate:activeKey":b[0]||(b[0]=d=>e.value=d)},{default:l(()=>[n(o(p),{key:"kanban",tab:"Kanban View"}),n(o(p),{key:"table",tab:"Table View"}),n(o(p),{key:"workflow",tab:"Workflow View"})]),_:1},8,["activeKey"]),e.value==="kanban"?(a(),i(v,{key:0,"kanban-repository":o(t),"kanban-stages-storage":o(u),"stage-run-repository":o(m)},null,8,["kanban-repository","kanban-stages-storage","stage-run-repository"])):s("",!0),e.value==="table"?(a(),i(K,{key:1,"kanban-repository":o(t)},null,8,["kanban-repository"])):s("",!0),e.value==="workflow"?(a(),i(E,{key:2,"kanban-repository":o(t),"workflow-api":o(k)},null,8,["kanban-repository","workflow-api"])):s("",!0)]),_:1}))}});export{yo as default};
//# sourceMappingURL=WorkflowThreads.91124367.js.map
