import{d as i,o as p,c as n,w as m,b as a,u as t}from"./index.b7b4bda7.js";import"./editor.9625acf0.js";import{W as s}from"./workspaces.a607659d.js";import{C as d}from"./ContentLayout.7bb666b7.js";import{_ as f,E as u}from"./View.vue_vue_type_script_setup_true_lang.03b7b6d7.js";import"./workspaceStore.be088758.js";import"./url.b5db0ec0.js";import"./colorHelpers.4deb51e0.js";import"./asyncComputed.03aca0e0.js";import"./record.c4002da6.js";import"./gateway.34f64afa.js";import"./popupNotifcation.75e3ec8b.js";import"./fetch.0c0bfc81.js";import"./SaveButton.af114484.js";import"./UnsavedChangesHandler.a75ff7c0.js";import"./ExclamationCircleOutlined.e47ecbae.js";import"./CrudView.59ddeda0.js";import"./router.5e6db19c.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.40847547.js";import"./BookOutlined.859ea6bf.js";import"./PhDotsThreeVertical.vue.56dbc503.js";import"./Badge.aaf7165e.js";import"./index.2876f94f.js";import"./polling.6fdb889c.js";import"./PhPencil.vue.d1759476.js";import"./index.c62cc8cf.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="3d1e166f-3158-4f95-8d5a-e58a4bf18944",o._sentryDebugIdIdentifier="sentry-dbid-3d1e166f-3158-4f95-8d5a-e58a4bf18944")}catch{}})();const F=i({__name:"EnvVarsEditor",setup(o){const r=new u;return(e,c)=>(p(),n(d,null,{default:m(()=>[a(f,{"env-var-repository":t(r),mode:"editor","file-opener":t(s)},null,8,["env-var-repository","file-opener"])]),_:1}))}});export{F as default};
//# sourceMappingURL=EnvVarsEditor.33914f1b.js.map
