import{_ as n,C as p}from"./View.vue_vue_type_script_setup_true_lang.03b7b6d7.js";import{d as i,ea as s,o as c,c as m,u as a}from"./index.b7b4bda7.js";import"./gateway.34f64afa.js";import"./popupNotifcation.75e3ec8b.js";import"./fetch.0c0bfc81.js";import"./record.c4002da6.js";import"./SaveButton.af114484.js";import"./UnsavedChangesHandler.a75ff7c0.js";import"./ExclamationCircleOutlined.e47ecbae.js";import"./CrudView.59ddeda0.js";import"./router.5e6db19c.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.40847547.js";import"./BookOutlined.859ea6bf.js";import"./url.b5db0ec0.js";import"./PhDotsThreeVertical.vue.56dbc503.js";import"./Badge.aaf7165e.js";import"./index.2876f94f.js";import"./asyncComputed.03aca0e0.js";import"./polling.6fdb889c.js";import"./PhPencil.vue.d1759476.js";import"./index.c62cc8cf.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="0cccc2c9-7e0c-4490-b4b5-05a332cdf730",o._sentryDebugIdIdentifier="sentry-dbid-0cccc2c9-7e0c-4490-b4b5-05a332cdf730")}catch{}})();const z=i({__name:"EnvVars",setup(o){const e=s().params.projectId,t=new p(e);return(d,f)=>(c(),m(n,{"env-var-repository":a(t),mode:"console"},null,8,["env-var-repository"]))}});export{z as default};
//# sourceMappingURL=EnvVars.0a659407.js.map
