import{B as f}from"./BookOutlined.859ea6bf.js";import{d as c,o as a,c as d,w as o,b as l,u as n,$ as u,Y as i,aG as p,aS as b,bT as y}from"./index.b7b4bda7.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="5ce65a85-5c8f-4fc1-9f81-156868862f23",t._sentryDebugIdIdentifier="sentry-dbid-5ce65a85-5c8f-4fc1-9f81-156868862f23")}catch{}})();const g=c({__name:"DocsButton",props:{path:{}},setup(t){return(e,r)=>{var s;return a(),d(n(y),{class:"docs-button",href:`https://docs.abstra.io/${(s=e.path)!=null?s:""}`,target:"_blank",type:"text",size:"small"},{icon:o(()=>[l(n(f))]),default:o(()=>[e.$slots.default?u(e.$slots,"default",{key:0}):(a(),i(b,{key:1},[p("Docs")],64))]),_:3},8,["href"])}}});export{g as _};
//# sourceMappingURL=DocsButton.vue_vue_type_script_setup_true_lang.40847547.js.map
