import"./App.vue_vue_type_style_index_0_lang.92016307.js";import{_ as c}from"./App.vue_vue_type_style_index_0_lang.92016307.js";import"./workspaceStore.be088758.js";import"./index.b7b4bda7.js";import"./url.b5db0ec0.js";import"./colorHelpers.4deb51e0.js";import"./PlayerConfigProvider.20b856a4.js";import"./index.9347e471.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="ca76bf0c-2586-4d80-9e24-777440e01562",e._sentryDebugIdIdentifier="sentry-dbid-ca76bf0c-2586-4d80-9e24-777440e01562")}catch{}})();export{c as default};
//# sourceMappingURL=App.078d15b4.js.map
